# swagger_client
<h5>JSON first</h5><br/>Our REST API exchanges data in the JSON data format. Every parameter you pass (with a few exceptions e.g. when you upload files) should therefore be formatted in JSON and our API will always return results in JSON as well.<br/><br/><h5>Very RESTful</h5><br/>Our API follows a very RESTful approach.<br/>Most importantly, we implemented the following four request methods for CRUD operations:<br/><br/>POST - Create a new record<br/>GET - Retrieve / read records without changing anything<br/>PATCH - Update an existing record<br/>DELETE - Delete one or more records<br/><br/><h5>HTTP Status codes</h5><br/>We also follow the most common HTTP status codes when outputting the API response:<br/><br/><b>2xx - Successful calls</b><br/>200 - Success<br/>201 - Created<br/><br/><b>4xx - Error codes</b><br/>400 - API error - inspect the body for detailed information about what went wrong. The most common error is \"code\":1062, which means, that a unique constraint was hit. For example if the name of the group is already in use.<br/>401 - Not authenticated - invalid access_token. Check if the access_token has expired or is incorrect.<br/>403 - Access denied<br/>404 - Call not available or no records found<br/><br/><b>5xx - API error - please contact support</b><br/><br/><h5>Response format</h5><br/>The API always returns data in the following format<br/><br/><code>{<br/>&nbsp;&nbsp;\"info\": {<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"count\": 0<br/>&nbsp;&nbsp;},<br/>&nbsp;&nbsp;\"value\": [<br/>&nbsp;&nbsp;&nbsp;{<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"key\": \"value\"<br/>&nbsp;&nbsp;&nbsp;}<br/>&nbsp;&nbsp;]<br/>}</code><br/><br/><h5>Recurring GET parameters</h5><br/><ul><li>_filter - a complex filter for filtering the result set based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.</li><li>_limit - the maximum number records returned.</li><li>_offset - pagination for the result-set</li><li>_expand - submit true to get all default fields of the resource</li><li>_fields - submit a comma-separated list of case-sensetive field-names to get the values of these fields in the response. You can use this the get values of custom attribute of recipients for example.</li></ul><br/><br/><h5>Filter language</h5><br/>The filter language for filtering results is based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.<br/>With the only restriction, that plain values must be surrounded by \". For example first_name==\"Max\"<br/>The following operators are supported<ul><li>Equals - <b>==</b></li><li>Not equals - <b>=ne=</b></li><li>Greater than - <b>=gt=</b></li><li>Greater than equals - <b>=ge=</b></li><li>Lower than - <b>=lt=</b></li><li>Lower than equals - <b>=le=</b></li><li>Like - <b>=like=</b> (in combination with % you are able to search for <i>starts with</i>, <i>ends with</i>, <i>contains</i>. For example first_name=like=\"%Max%\")</li><li>Not like - <b>=nlike=</b></li><li>Logical and - <b>;</b></li><li>Logical or - <b>,</b></li></ul><br/><br/><h5>How to make Calls?</h5><br/>After you authenticated and received a valid access_token, you have to pass it in every consecutive call. Use the Authorization header for that purpose as follows:<br/><code>xhr.setRequestHeader(\"Authorization\", \"Bearer \" + your_access_token);</code><br/><br/>Every call takes additional parameters that can be used to modify the request. These parameters should be passed as JSON<br/><code>var params = {<br/>&nbsp;&nbsp;\"key\"= \"value\"<br/>}<br/>xhr.send(JSON.stringify(params));</code><br/><br/><h5>Sending transactional emails</h5><br/>It is very important to understand the following concept in order for you to take full advantage of our powerful personalization features and our detailed reports when sending transactional emails.<br/><br/>First, you will have to create a new mailing. We recommend that you create that mailing through our UI in order to take full advantage of our powerful newsletter builder. This way, we will automatically create cross-client optimized and responsive HTML. Yet another advantage lies in the possibility for other users (e.g. the marketing team) to change the layout or the content of the mailing without having to contact the developer (you).<br/><br/>Of course, it is also possible to create a mailing through the API. When doing so, you can also take advantage of our cross-client optimized responsive HTML by passing us JSON or YAML according to the Newsletter2Go Markup Language.<br/>No matter how you create the mailing, try to create *one* reusable template. You can customize individual emails by inserting placeholders for personalized fields such as name, products or other information that will be filled through an API call when sending.<br/><br/>By only creating one template, you can take advantage of our full reporting since all emails will be treated part of a \"campaign\". When you change that template, we will create a new version of the mailing in the background and you will be able to see the difference in performance in the reports. This is particularily useful when you are trying to test and optimize different versions of transactional emails such as a sign up email.<br/><br/>After creating a mailing, you will have access to its ID. Use that ID to actually send the email in the next step.<br/><br/>When sending an email, you have to pass the newsletter ID and information about the recipient. Either pass the recipient ID or pass all the recipient's data (including the e-mail-address) as JSON.<br/><br/>If you only pass the recipient ID, we will use his or her data from your list to personalize the mailing. If you pass full recipient data as JSON, we will try to merge the data with existing data from your list.<br/><br/>You can also pass additional data such as product data which is not saved in your list. Just make sure that the placeholders in the source of the mailing correspond to the parameters that you are passing.<br/>This way you can also create for-loops which can be useful if you pass different amounts of data for each recipient (e.g. a purchase confirmation where you want to list all the products that were just bought).

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build date: 2016-06-08T07:00:07.445Z
- Build package: class io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: OAuth
swagger_client.configuration.access_token = 'YOUR_ACCESS_TOKEN'
# create an instance of the API class
api_instance = swagger_client.AttributeApi
attribute = swagger_client.AttributePost() # AttributePost | the data to save

try:
    # creates a new attribute
    api_response = api_instance.create_attribute(attribute)
    pprint(api_response)
except ApiException as e:
    print "Exception when calling AttributeApi->create_attribute: %s\n" % e

```

## Documentation for API Endpoints

All URIs are relative to *https://api.newsletter2go.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AttributeApi* | [**create_attribute**](docs/AttributeApi.md#create_attribute) | **POST** /attributes | creates a new attribute
*AttributeApi* | [**delete_attribute**](docs/AttributeApi.md#delete_attribute) | **DELETE** /lists/{lid}/attributes/{id} | delete the attribute
*AttributeApi* | [**get_attributes**](docs/AttributeApi.md#get_attributes) | **GET** /lists/{lid}/attributes | get all Attributes of selected list
*AttributeApi* | [**update_attribute**](docs/AttributeApi.md#update_attribute) | **PATCH** /attributes/{id} | update the attribute
*AuthorizationApi* | [**get_token**](docs/AuthorizationApi.md#get_token) | **POST** /oauth/v2/token | Endpoint for retrieving a token
*CompanyApi* | [**get_company**](docs/CompanyApi.md#get_company) | **GET** /companies | get the details of a company
*CompanyApi* | [**update_company**](docs/CompanyApi.md#update_company) | **PATCH** /companies/{id} | update the Company
*GroupApi* | [**add_recipient_to_group**](docs/GroupApi.md#add_recipient_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients/{id} | add single recipient to group
*GroupApi* | [**add_recipients_to_group**](docs/GroupApi.md#add_recipients_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients | add all Recipients to the given group
*GroupApi* | [**create_group**](docs/GroupApi.md#create_group) | **POST** /groups | creates a new group
*GroupApi* | [**delete_group**](docs/GroupApi.md#delete_group) | **DELETE** /groups/{id} | delete the Group
*GroupApi* | [**get_groups**](docs/GroupApi.md#get_groups) | **GET** /lists/{lid}/groups | get all Group of selected list
*GroupApi* | [**get_recipients_by_group**](docs/GroupApi.md#get_recipients_by_group) | **GET** /lists/{lid}/groups/{gid}/recipients | get all Recipients of selected group
*GroupApi* | [**remove_recipient_from_group**](docs/GroupApi.md#remove_recipient_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients/{id} | remove single recipient from group
*GroupApi* | [**remove_recipients_from_group**](docs/GroupApi.md#remove_recipients_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients | remove all Recipients from given group
*GroupApi* | [**update_group**](docs/GroupApi.md#update_group) | **PATCH** /groups/{id} | update the Group
*ListApi* | [**create_list**](docs/ListApi.md#create_list) | **POST** /lists | creates a new list
*ListApi* | [**delete_list**](docs/ListApi.md#delete_list) | **DELETE** /lists/{id} | delete the List
*ListApi* | [**get_lists**](docs/ListApi.md#get_lists) | **GET** /lists | get all lists
*ListApi* | [**get_recipients**](docs/ListApi.md#get_recipients) | **GET** /lists/{lid}/recipients | get all Recipients of selected list
*ListApi* | [**remove_recipients_from_list**](docs/ListApi.md#remove_recipients_from_list) | **DELETE** /lists/{lid}/recipients | remove all Recipients from selected list
*ListApi* | [**update_list**](docs/ListApi.md#update_list) | **PATCH** /lists/{id} | update the List
*ListApi* | [**update_recipients**](docs/ListApi.md#update_recipients) | **PATCH** /lists/{lid}/recipients | update all Recipients in selected list
*NewsletterApi* | [**create_newsletter**](docs/NewsletterApi.md#create_newsletter) | **POST** /lists/{lid}/newsletters | creates a new newsletter
*NewsletterApi* | [**get_newsletter**](docs/NewsletterApi.md#get_newsletter) | **GET** /newsletters/{id} | get one newsletter
*NewsletterApi* | [**get_newsletters**](docs/NewsletterApi.md#get_newsletters) | **GET** /lists/{lid}/newsletters | get all newsletters of the given list
*NewsletterApi* | [**get_reports**](docs/NewsletterApi.md#get_reports) | **GET** /lists/{lid}/newsletters/{nid}/aggregations | get reports for the newsletter aggregated by days
*NewsletterApi* | [**send_newsletter**](docs/NewsletterApi.md#send_newsletter) | **POST** /newsletters/{id}/send | Sends the newsletter to a list or group
*NewsletterApi* | [**update_newsletter**](docs/NewsletterApi.md#update_newsletter) | **PATCH** /newsletters/{id} | update the Newsletter
*RecipientApi* | [**add_recipient_to_group**](docs/RecipientApi.md#add_recipient_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients/{id} | add single recipient to group
*RecipientApi* | [**add_recipients_to_group**](docs/RecipientApi.md#add_recipients_to_group) | **POST** /lists/{lid}/groups/{gid}/recipients | add all Recipients to the given group
*RecipientApi* | [**create_recipient**](docs/RecipientApi.md#create_recipient) | **POST** /recipients | create new recipient(s) or updates existing ones
*RecipientApi* | [**delete_recipient**](docs/RecipientApi.md#delete_recipient) | **DELETE** /lists/{lid}/recipients/{id} | delete the recipient
*RecipientApi* | [**get_recipients**](docs/RecipientApi.md#get_recipients) | **GET** /lists/{lid}/recipients | get all Recipients of selected list
*RecipientApi* | [**get_recipients_by_group**](docs/RecipientApi.md#get_recipients_by_group) | **GET** /lists/{lid}/groups/{gid}/recipients | get all Recipients of selected group
*RecipientApi* | [**import_recipients_init**](docs/RecipientApi.md#import_recipients_init) | **POST** /lists/{lid}/recipients/import/init | Initialize the import of recipients by file
*RecipientApi* | [**import_recipients_save**](docs/RecipientApi.md#import_recipients_save) | **POST** /lists/{lid}/recipients/import/save | Start the import recipients by file
*RecipientApi* | [**import_recipients_statistics**](docs/RecipientApi.md#import_recipients_statistics) | **GET** /import/{id}/info | Get statistics about the import by file
*RecipientApi* | [**remove_recipient_from_group**](docs/RecipientApi.md#remove_recipient_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients/{id} | remove single recipient from group
*RecipientApi* | [**remove_recipients_from_group**](docs/RecipientApi.md#remove_recipients_from_group) | **DELETE** /lists/{lid}/groups/{gid}/recipients | remove all Recipients from given group
*RecipientApi* | [**remove_recipients_from_list**](docs/RecipientApi.md#remove_recipients_from_list) | **DELETE** /lists/{lid}/recipients | remove all Recipients from selected list
*RecipientApi* | [**subscribe_recipient**](docs/RecipientApi.md#subscribe_recipient) | **POST** /forms/submit/{code} | Creates a new recipient and sends a DOI-Mail
*RecipientApi* | [**update_recipient**](docs/RecipientApi.md#update_recipient) | **PATCH** /lists/{lid}/recipients/{id} | update the recipient.
*RecipientApi* | [**update_recipients**](docs/RecipientApi.md#update_recipients) | **PATCH** /lists/{lid}/recipients | update all Recipients in selected list
*ReportApi* | [**get_reports**](docs/ReportApi.md#get_reports) | **GET** /lists/{lid}/newsletters/{nid}/aggregations | get reports for the newsletter aggregated by days
*UserApi* | [**get_users**](docs/UserApi.md#get_users) | **GET** /users | get all users of the company where the current user has access to
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PATCH** /users/{id} | update the user


## Documentation For Models

 - [ApiResponseDelete](docs/ApiResponseDelete.md)
 - [ApiResponsePost](docs/ApiResponsePost.md)
 - [AttributeGet](docs/AttributeGet.md)
 - [AttributePatch](docs/AttributePatch.md)
 - [AttributePost](docs/AttributePost.md)
 - [AttributeResponse](docs/AttributeResponse.md)
 - [CompanyGet](docs/CompanyGet.md)
 - [CompanyPatch](docs/CompanyPatch.md)
 - [CompanyResponse](docs/CompanyResponse.md)
 - [Data](docs/Data.md)
 - [Error](docs/Error.md)
 - [GroupGet](docs/GroupGet.md)
 - [GroupPatch](docs/GroupPatch.md)
 - [GroupPost](docs/GroupPost.md)
 - [GroupResponse](docs/GroupResponse.md)
 - [ImportGet](docs/ImportGet.md)
 - [ImportResponse](docs/ImportResponse.md)
 - [Info](docs/Info.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [ListGet](docs/ListGet.md)
 - [ListPost](docs/ListPost.md)
 - [ListResponse](docs/ListResponse.md)
 - [ModelWithId](docs/ModelWithId.md)
 - [NewsletterGet](docs/NewsletterGet.md)
 - [NewsletterPost](docs/NewsletterPost.md)
 - [NewsletterResponse](docs/NewsletterResponse.md)
 - [NewsletterSend](docs/NewsletterSend.md)
 - [PatchResponse](docs/PatchResponse.md)
 - [RecipientGet](docs/RecipientGet.md)
 - [RecipientPatch](docs/RecipientPatch.md)
 - [RecipientPost](docs/RecipientPost.md)
 - [RecipientResponse](docs/RecipientResponse.md)
 - [RecipientSimple](docs/RecipientSimple.md)
 - [RecipientSubscribe](docs/RecipientSubscribe.md)
 - [RecipientSubscribeRecipient](docs/RecipientSubscribeRecipient.md)
 - [RecipientSubscribeResponse](docs/RecipientSubscribeResponse.md)
 - [RecipientSubscribeResponseValue](docs/RecipientSubscribeResponseValue.md)
 - [RecipientSubscribeResponseValueResult](docs/RecipientSubscribeResponseValueResult.md)
 - [RecipientSubscribeResponseValueResultError](docs/RecipientSubscribeResponseValueResultError.md)
 - [RecipientSubscribeResponseValueResultErrorRecipients](docs/RecipientSubscribeResponseValueResultErrorRecipients.md)
 - [RecipientSubscribeResponseValueResultSuccess](docs/RecipientSubscribeResponseValueResultSuccess.md)
 - [Report](docs/Report.md)
 - [ReportResponse](docs/ReportResponse.md)
 - [Token](docs/Token.md)
 - [UserGet](docs/UserGet.md)
 - [UserPatch](docs/UserPatch.md)
 - [UserResponse](docs/UserResponse.md)


## Documentation For Authorization


## OAuth

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: /oauth/v2/token
- **Scopes**: N/A

## Basic

- **Type**: HTTP basic authentication


## Author

support@newsletter2go.com

