# coding: utf-8

"""
    Newsletter2Go-API (https://api.newsletter2go.com)

    <h5>JSON first</h5><br/>Our REST API exchanges data in the JSON data format. Every parameter you pass (with a few exceptions e.g. when you upload files) should therefore be formatted in JSON and our API will always return results in JSON as well.<br/><br/><h5>Very RESTful</h5><br/>Our API follows a very RESTful approach.<br/>Most importantly, we implemented the following four request methods for CRUD operations:<br/><br/>POST - Create a new record<br/>GET - Retrieve / read records without changing anything<br/>PATCH - Update an existing record<br/>DELETE - Delete one or more records<br/><br/><h5>HTTP Status codes</h5><br/>We also follow the most common HTTP status codes when outputting the API response:<br/><br/><b>2xx - Successful calls</b><br/>200 - Success<br/>201 - Created<br/><br/><b>4xx - Error codes</b><br/>400 - API error - inspect the body for detailed information about what went wrong. The most common error is \"code\":1062, which means, that a unique constraint was hit. For example if the name of the group is already in use.<br/>401 - Not authenticated - invalid access_token. Check if the access_token has expired or is incorrect.<br/>403 - Access denied<br/>404 - Call not available or no records found<br/><br/><b>5xx - API error - please contact support</b><br/><br/><h5>Response format</h5><br/>The API always returns data in the following format<br/><br/><code>{<br/>&nbsp;&nbsp;\"info\": {<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"count\": 0<br/>&nbsp;&nbsp;},<br/>&nbsp;&nbsp;\"value\": [<br/>&nbsp;&nbsp;&nbsp;{<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"key\": \"value\"<br/>&nbsp;&nbsp;&nbsp;}<br/>&nbsp;&nbsp;]<br/>}</code><br/><br/><h5>Recurring GET parameters</h5><br/><ul><li>_filter - a complex filter for filtering the result set based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.</li><li>_limit - the maximum number records returned.</li><li>_offset - pagination for the result-set</li><li>_expand - submit true to get all default fields of the resource</li><li>_fields - submit a comma-separated list of case-sensetive field-names to get the values of these fields in the response. You can use this the get values of custom attribute of recipients for example.</li></ul><br/><br/><h5>Filter language</h5><br/>The filter language for filtering results is based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.<br/>With the only restriction, that plain values must be surrounded by \". For example first_name==\"Max\"<br/>The following operators are supported<ul><li>Equals - <b>==</b></li><li>Not equals - <b>=ne=</b></li><li>Greater than - <b>=gt=</b></li><li>Greater than equals - <b>=ge=</b></li><li>Lower than - <b>=lt=</b></li><li>Lower than equals - <b>=le=</b></li><li>Like - <b>=like=</b> (in combination with % you are able to search for <i>starts with</i>, <i>ends with</i>, <i>contains</i>. For example first_name=like=\"%Max%\")</li><li>Not like - <b>=nlike=</b></li><li>Logical and - <b>;</b></li><li>Logical or - <b>,</b></li></ul><br/><br/><h5>How to make Calls?</h5><br/>After you authenticated and received a valid access_token, you have to pass it in every consecutive call. Use the Authorization header for that purpose as follows:<br/><code>xhr.setRequestHeader(\"Authorization\", \"Bearer \" + your_access_token);</code><br/><br/>Every call takes additional parameters that can be used to modify the request. These parameters should be passed as JSON<br/><code>var params = {<br/>&nbsp;&nbsp;\"key\"= \"value\"<br/>}<br/>xhr.send(JSON.stringify(params));</code><br/><br/><h5>Sending transactional emails</h5><br/>It is very important to understand the following concept in order for you to take full advantage of our powerful personalization features and our detailed reports when sending transactional emails.<br/><br/>First, you will have to create a new mailing. We recommend that you create that mailing through our UI in order to take full advantage of our powerful newsletter builder. This way, we will automatically create cross-client optimized and responsive HTML. Yet another advantage lies in the possibility for other users (e.g. the marketing team) to change the layout or the content of the mailing without having to contact the developer (you).<br/><br/>Of course, it is also possible to create a mailing through the API. When doing so, you can also take advantage of our cross-client optimized responsive HTML by passing us JSON or YAML according to the Newsletter2Go Markup Language.<br/>No matter how you create the mailing, try to create *one* reusable template. You can customize individual emails by inserting placeholders for personalized fields such as name, products or other information that will be filled through an API call when sending.<br/><br/>By only creating one template, you can take advantage of our full reporting since all emails will be treated part of a \"campaign\". When you change that template, we will create a new version of the mailing in the background and you will be able to see the difference in performance in the reports. This is particularily useful when you are trying to test and optimize different versions of transactional emails such as a sign up email.<br/><br/>After creating a mailing, you will have access to its ID. Use that ID to actually send the email in the next step.<br/><br/>When sending an email, you have to pass the newsletter ID and information about the recipient. Either pass the recipient ID or pass all the recipient's data (including the e-mail-address) as JSON.<br/><br/>If you only pass the recipient ID, we will use his or her data from your list to personalize the mailing. If you pass full recipient data as JSON, we will try to merge the data with existing data from your list.<br/><br/>You can also pass additional data such as product data which is not saved in your list. Just make sure that the placeholders in the source of the mailing correspond to the parameters that you are passing.<br/>This way you can also create for-loops which can be useful if you pass different amounts of data for each recipient (e.g. a purchase confirmation where you want to list all the products that were just bought).

    OpenAPI spec version: 1.0.0
    Contact: support@newsletter2go.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
    
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at
    
        http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class NewsletterGet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NewsletterGet - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'list_id': 'str',
            'id': 'str',
            'type': 'str',
            'name': 'str',
            'description': 'str',
            'has_open_tracking': 'bool',
            'has_click_tracking': 'bool',
            'has_conversion_tracking': 'bool'
        }

        self.attribute_map = {
            'list_id': 'list_id',
            'id': 'id',
            'type': 'type',
            'name': 'name',
            'description': 'description',
            'has_open_tracking': 'has_open_tracking',
            'has_click_tracking': 'has_click_tracking',
            'has_conversion_tracking': 'has_conversion_tracking'
        }

        self._list_id = None
        self._id = None
        self._type = 'default'
        self._name = None
        self._description = None
        self._has_open_tracking = None
        self._has_click_tracking = None
        self._has_conversion_tracking = None

    @property
    def list_id(self):
        """
        Gets the list_id of this NewsletterGet.
        the list_id where the newsletter belongs to

        :return: The list_id of this NewsletterGet.
        :rtype: str
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """
        Sets the list_id of this NewsletterGet.
        the list_id where the newsletter belongs to

        :param list_id: The list_id of this NewsletterGet.
        :type: str
        """
        
        self._list_id = list_id

    @property
    def id(self):
        """
        Gets the id of this NewsletterGet.
        the id of the newsletter

        :return: The id of this NewsletterGet.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NewsletterGet.
        the id of the newsletter

        :param id: The id of this NewsletterGet.
        :type: str
        """
        
        self._id = id

    @property
    def type(self):
        """
        Gets the type of this NewsletterGet.
        the type of newsletter

        :return: The type of this NewsletterGet.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this NewsletterGet.
        the type of newsletter

        :param type: The type of this NewsletterGet.
        :type: str
        """
        allowed_values = ["default", "ab", "trigger", "transaction"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """
        Gets the name of this NewsletterGet.
        a name for the newsletter

        :return: The name of this NewsletterGet.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NewsletterGet.
        a name for the newsletter

        :param name: The name of this NewsletterGet.
        :type: str
        """
        
        if not name:
            raise ValueError("Invalid value for `name`, must not be `None`")
        if len(name) > 64: 
            raise ValueError("Invalid value for `name`, length must be less than `64`")

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this NewsletterGet.
        a description for the newsletter

        :return: The description of this NewsletterGet.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this NewsletterGet.
        a description for the newsletter

        :param description: The description of this NewsletterGet.
        :type: str
        """
        
        if not description:
            raise ValueError("Invalid value for `description`, must not be `None`")
        if len(description) > 128: 
            raise ValueError("Invalid value for `description`, length must be less than `128`")

        self._description = description

    @property
    def has_open_tracking(self):
        """
        Gets the has_open_tracking of this NewsletterGet.
        weither open_tracking is enabled or not

        :return: The has_open_tracking of this NewsletterGet.
        :rtype: bool
        """
        return self._has_open_tracking

    @has_open_tracking.setter
    def has_open_tracking(self, has_open_tracking):
        """
        Sets the has_open_tracking of this NewsletterGet.
        weither open_tracking is enabled or not

        :param has_open_tracking: The has_open_tracking of this NewsletterGet.
        :type: bool
        """
        
        self._has_open_tracking = has_open_tracking

    @property
    def has_click_tracking(self):
        """
        Gets the has_click_tracking of this NewsletterGet.
        weither click_tracking is enabled or not

        :return: The has_click_tracking of this NewsletterGet.
        :rtype: bool
        """
        return self._has_click_tracking

    @has_click_tracking.setter
    def has_click_tracking(self, has_click_tracking):
        """
        Sets the has_click_tracking of this NewsletterGet.
        weither click_tracking is enabled or not

        :param has_click_tracking: The has_click_tracking of this NewsletterGet.
        :type: bool
        """
        
        self._has_click_tracking = has_click_tracking

    @property
    def has_conversion_tracking(self):
        """
        Gets the has_conversion_tracking of this NewsletterGet.
        weither click_tracking is enabled or not

        :return: The has_conversion_tracking of this NewsletterGet.
        :rtype: bool
        """
        return self._has_conversion_tracking

    @has_conversion_tracking.setter
    def has_conversion_tracking(self, has_conversion_tracking):
        """
        Sets the has_conversion_tracking of this NewsletterGet.
        weither click_tracking is enabled or not

        :param has_conversion_tracking: The has_conversion_tracking of this NewsletterGet.
        :type: bool
        """
        
        self._has_conversion_tracking = has_conversion_tracking

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

