# coding: utf-8

"""
    Newsletter2Go-API (https://api.newsletter2go.com)

    <h5>JSON first</h5><br/>Our REST API exchanges data in the JSON data format. Every parameter you pass (with a few exceptions e.g. when you upload files) should therefore be formatted in JSON and our API will always return results in JSON as well.<br/><br/><h5>Very RESTful</h5><br/>Our API follows a very RESTful approach.<br/>Most importantly, we implemented the following four request methods for CRUD operations:<br/><br/>POST - Create a new record<br/>GET - Retrieve / read records without changing anything<br/>PATCH - Update an existing record<br/>DELETE - Delete one or more records<br/><br/><h5>HTTP Status codes</h5><br/>We also follow the most common HTTP status codes when outputting the API response:<br/><br/><b>2xx - Successful calls</b><br/>200 - Success<br/>201 - Created<br/><br/><b>4xx - Error codes</b><br/>400 - API error - inspect the body for detailed information about what went wrong. The most common error is \"code\":1062, which means, that a unique constraint was hit. For example if the name of the group is already in use.<br/>401 - Not authenticated - invalid access_token. Check if the access_token has expired or is incorrect.<br/>403 - Access denied<br/>404 - Call not available or no records found<br/><br/><b>5xx - API error - please contact support</b><br/><br/><h5>Response format</h5><br/>The API always returns data in the following format<br/><br/><code>{<br/>&nbsp;&nbsp;\"info\": {<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"count\": 0<br/>&nbsp;&nbsp;},<br/>&nbsp;&nbsp;\"value\": [<br/>&nbsp;&nbsp;&nbsp;{<br/>&nbsp;&nbsp;&nbsp;&nbsp;\"key\": \"value\"<br/>&nbsp;&nbsp;&nbsp;}<br/>&nbsp;&nbsp;]<br/>}</code><br/><br/><h5>Recurring GET parameters</h5><br/><ul><li>_filter - a complex filter for filtering the result set based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.</li><li>_limit - the maximum number records returned.</li><li>_offset - pagination for the result-set</li><li>_expand - submit true to get all default fields of the resource</li><li>_fields - submit a comma-separated list of case-sensetive field-names to get the values of these fields in the response. You can use this the get values of custom attribute of recipients for example.</li></ul><br/><br/><h5>Filter language</h5><br/>The filter language for filtering results is based on <a target=\"blank\" href=\"https://tools.ietf.org/html/draft-nottingham-atompub-fiql-00\">FIQL</a>.<br/>With the only restriction, that plain values must be surrounded by \". For example first_name==\"Max\"<br/>The following operators are supported<ul><li>Equals - <b>==</b></li><li>Not equals - <b>=ne=</b></li><li>Greater than - <b>=gt=</b></li><li>Greater than equals - <b>=ge=</b></li><li>Lower than - <b>=lt=</b></li><li>Lower than equals - <b>=le=</b></li><li>Like - <b>=like=</b> (in combination with % you are able to search for <i>starts with</i>, <i>ends with</i>, <i>contains</i>. For example first_name=like=\"%Max%\")</li><li>Not like - <b>=nlike=</b></li><li>Logical and - <b>;</b></li><li>Logical or - <b>,</b></li></ul><br/><br/><h5>How to make Calls?</h5><br/>After you authenticated and received a valid access_token, you have to pass it in every consecutive call. Use the Authorization header for that purpose as follows:<br/><code>xhr.setRequestHeader(\"Authorization\", \"Bearer \" + your_access_token);</code><br/><br/>Every call takes additional parameters that can be used to modify the request. These parameters should be passed as JSON<br/><code>var params = {<br/>&nbsp;&nbsp;\"key\"= \"value\"<br/>}<br/>xhr.send(JSON.stringify(params));</code><br/><br/><h5>Sending transactional emails</h5><br/>It is very important to understand the following concept in order for you to take full advantage of our powerful personalization features and our detailed reports when sending transactional emails.<br/><br/>First, you will have to create a new mailing. We recommend that you create that mailing through our UI in order to take full advantage of our powerful newsletter builder. This way, we will automatically create cross-client optimized and responsive HTML. Yet another advantage lies in the possibility for other users (e.g. the marketing team) to change the layout or the content of the mailing without having to contact the developer (you).<br/><br/>Of course, it is also possible to create a mailing through the API. When doing so, you can also take advantage of our cross-client optimized responsive HTML by passing us JSON or YAML according to the Newsletter2Go Markup Language.<br/>No matter how you create the mailing, try to create *one* reusable template. You can customize individual emails by inserting placeholders for personalized fields such as name, products or other information that will be filled through an API call when sending.<br/><br/>By only creating one template, you can take advantage of our full reporting since all emails will be treated part of a \"campaign\". When you change that template, we will create a new version of the mailing in the background and you will be able to see the difference in performance in the reports. This is particularily useful when you are trying to test and optimize different versions of transactional emails such as a sign up email.<br/><br/>After creating a mailing, you will have access to its ID. Use that ID to actually send the email in the next step.<br/><br/>When sending an email, you have to pass the newsletter ID and information about the recipient. Either pass the recipient ID or pass all the recipient's data (including the e-mail-address) as JSON.<br/><br/>If you only pass the recipient ID, we will use his or her data from your list to personalize the mailing. If you pass full recipient data as JSON, we will try to merge the data with existing data from your list.<br/><br/>You can also pass additional data such as product data which is not saved in your list. Just make sure that the placeholders in the source of the mailing correspond to the parameters that you are passing.<br/>This way you can also create for-loops which can be useful if you pass different amounts of data for each recipient (e.g. a purchase confirmation where you want to list all the products that were just bought).

    OpenAPI spec version: 1.0.0
    Contact: support@newsletter2go.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
    
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at
    
        http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class RecipientGet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RecipientGet - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'email': 'str',
            'phone': 'str',
            'gender': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'is_unsubscribed': 'bool',
            'is_blacklisted': 'bool',
            'custom_attribute_': 'str',
            'rating': 'int',
            'statistic_mails_received': 'int',
            'statistic_mails_opened': 'int',
            'statistic_mails_unique_opened': 'int',
            'statistic_mails_clicked': 'int',
            'statistic_conversions': 'int',
            'statistic_conversions_sum': 'float',
            'statistic_last_mail_action': 'datetime',
            'statistic_last_mail_received': 'datetime',
            'statistic_last_mail_opened': 'datetime',
            'statistic_last_mail_clicked': 'datetime',
            'statistic_last_mail_converted': 'datetime',
            'statistic_last_useragent_device': 'str',
            'statistic_last_useragent_family': 'str',
            'statistic_last_latitude': 'float',
            'statistic_last_longitude': 'float',
            'statistic_last_blacklist_list': 'datetime',
            'statistic_last_unsubscribe_list': 'datetime',
            'statistic_last_blacklist_list_reason': 'str',
            'statistic_last_unsubscribe_list_reason': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'email': 'email',
            'phone': 'phone',
            'gender': 'gender',
            'first_name': 'first_name',
            'last_name': 'last_name',
            'is_unsubscribed': 'is_unsubscribed',
            'is_blacklisted': 'is_blacklisted',
            'custom_attribute_': '_custom_attribute_',
            'rating': 'rating',
            'statistic_mails_received': 'statistic_mails_received',
            'statistic_mails_opened': 'statistic_mails_opened',
            'statistic_mails_unique_opened': 'statistic_mails_unique_opened',
            'statistic_mails_clicked': 'statistic_mails_clicked',
            'statistic_conversions': 'statistic_conversions',
            'statistic_conversions_sum': 'statistic_conversions_sum',
            'statistic_last_mail_action': 'statistic_last_mail_action',
            'statistic_last_mail_received': 'statistic_last_mail_received',
            'statistic_last_mail_opened': 'statistic_last_mail_opened',
            'statistic_last_mail_clicked': 'statistic_last_mail_clicked',
            'statistic_last_mail_converted': 'statistic_last_mail_converted',
            'statistic_last_useragent_device': 'statistic_last_useragent_device',
            'statistic_last_useragent_family': 'statistic_last_useragent_family',
            'statistic_last_latitude': 'statistic_last_latitude',
            'statistic_last_longitude': 'statistic_last_longitude',
            'statistic_last_blacklist_list': 'statistic_last_blacklist_list',
            'statistic_last_unsubscribe_list': 'statistic_last_unsubscribe_list',
            'statistic_last_blacklist_list_reason': 'statistic_last_blacklist_list_reason',
            'statistic_last_unsubscribe_list_reason': 'statistic_last_unsubscribe_list_reason'
        }

        self._id = None
        self._email = None
        self._phone = None
        self._gender = None
        self._first_name = None
        self._last_name = None
        self._is_unsubscribed = None
        self._is_blacklisted = None
        self._custom_attribute_ = None
        self._rating = None
        self._statistic_mails_received = None
        self._statistic_mails_opened = None
        self._statistic_mails_unique_opened = None
        self._statistic_mails_clicked = None
        self._statistic_conversions = None
        self._statistic_conversions_sum = None
        self._statistic_last_mail_action = None
        self._statistic_last_mail_received = None
        self._statistic_last_mail_opened = None
        self._statistic_last_mail_clicked = None
        self._statistic_last_mail_converted = None
        self._statistic_last_useragent_device = None
        self._statistic_last_useragent_family = None
        self._statistic_last_latitude = None
        self._statistic_last_longitude = None
        self._statistic_last_blacklist_list = None
        self._statistic_last_unsubscribe_list = None
        self._statistic_last_blacklist_list_reason = None
        self._statistic_last_unsubscribe_list_reason = None

    @property
    def id(self):
        """
        Gets the id of this RecipientGet.
        the id of the recipient

        :return: The id of this RecipientGet.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RecipientGet.
        the id of the recipient

        :param id: The id of this RecipientGet.
        :type: str
        """
        
        self._id = id

    @property
    def email(self):
        """
        Gets the email of this RecipientGet.
        the email of the recipient

        :return: The email of this RecipientGet.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this RecipientGet.
        the email of the recipient

        :param email: The email of this RecipientGet.
        :type: str
        """
        
        if not email:
            raise ValueError("Invalid value for `email`, must not be `None`")
        if len(email) > 64: 
            raise ValueError("Invalid value for `email`, length must be less than `64`")

        self._email = email

    @property
    def phone(self):
        """
        Gets the phone of this RecipientGet.
        the phone number of the recipient

        :return: The phone of this RecipientGet.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this RecipientGet.
        the phone number of the recipient

        :param phone: The phone of this RecipientGet.
        :type: str
        """
        
        if not phone:
            raise ValueError("Invalid value for `phone`, must not be `None`")
        if len(phone) > 32: 
            raise ValueError("Invalid value for `phone`, length must be less than `32`")

        self._phone = phone

    @property
    def gender(self):
        """
        Gets the gender of this RecipientGet.
        m for male and f for female

        :return: The gender of this RecipientGet.
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """
        Sets the gender of this RecipientGet.
        m for male and f for female

        :param gender: The gender of this RecipientGet.
        :type: str
        """
        allowed_values = ["m", "f"]
        if gender not in allowed_values:
            raise ValueError(
                "Invalid value for `gender`, must be one of {0}"
                .format(allowed_values)
            )

        self._gender = gender

    @property
    def first_name(self):
        """
        Gets the first_name of this RecipientGet.
        the first name of the recipient

        :return: The first_name of this RecipientGet.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this RecipientGet.
        the first name of the recipient

        :param first_name: The first_name of this RecipientGet.
        :type: str
        """
        
        if not first_name:
            raise ValueError("Invalid value for `first_name`, must not be `None`")
        if len(first_name) > 64: 
            raise ValueError("Invalid value for `first_name`, length must be less than `64`")

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this RecipientGet.
        the last name of the recipient

        :return: The last_name of this RecipientGet.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this RecipientGet.
        the last name of the recipient

        :param last_name: The last_name of this RecipientGet.
        :type: str
        """
        
        if not last_name:
            raise ValueError("Invalid value for `last_name`, must not be `None`")
        if len(last_name) > 64: 
            raise ValueError("Invalid value for `last_name`, length must be less than `64`")

        self._last_name = last_name

    @property
    def is_unsubscribed(self):
        """
        Gets the is_unsubscribed of this RecipientGet.
        weither the recipient is unsubscribed or not

        :return: The is_unsubscribed of this RecipientGet.
        :rtype: bool
        """
        return self._is_unsubscribed

    @is_unsubscribed.setter
    def is_unsubscribed(self, is_unsubscribed):
        """
        Sets the is_unsubscribed of this RecipientGet.
        weither the recipient is unsubscribed or not

        :param is_unsubscribed: The is_unsubscribed of this RecipientGet.
        :type: bool
        """
        
        self._is_unsubscribed = is_unsubscribed

    @property
    def is_blacklisted(self):
        """
        Gets the is_blacklisted of this RecipientGet.
        weither the recipient is blacklisted or not

        :return: The is_blacklisted of this RecipientGet.
        :rtype: bool
        """
        return self._is_blacklisted

    @is_blacklisted.setter
    def is_blacklisted(self, is_blacklisted):
        """
        Sets the is_blacklisted of this RecipientGet.
        weither the recipient is blacklisted or not

        :param is_blacklisted: The is_blacklisted of this RecipientGet.
        :type: bool
        """
        
        self._is_blacklisted = is_blacklisted

    @property
    def custom_attribute_(self):
        """
        Gets the custom_attribute_ of this RecipientGet.
        every custom attribute can be submitted

        :return: The custom_attribute_ of this RecipientGet.
        :rtype: str
        """
        return self._custom_attribute_

    @custom_attribute_.setter
    def custom_attribute_(self, custom_attribute_):
        """
        Sets the custom_attribute_ of this RecipientGet.
        every custom attribute can be submitted

        :param custom_attribute_: The custom_attribute_ of this RecipientGet.
        :type: str
        """
        
        self._custom_attribute_ = custom_attribute_

    @property
    def rating(self):
        """
        Gets the rating of this RecipientGet.
        Indicating the quality of the recipient. Between 0 and 5

        :return: The rating of this RecipientGet.
        :rtype: int
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """
        Sets the rating of this RecipientGet.
        Indicating the quality of the recipient. Between 0 and 5

        :param rating: The rating of this RecipientGet.
        :type: int
        """
        
        self._rating = rating

    @property
    def statistic_mails_received(self):
        """
        Gets the statistic_mails_received of this RecipientGet.
        how many newsletters the recipient has received

        :return: The statistic_mails_received of this RecipientGet.
        :rtype: int
        """
        return self._statistic_mails_received

    @statistic_mails_received.setter
    def statistic_mails_received(self, statistic_mails_received):
        """
        Sets the statistic_mails_received of this RecipientGet.
        how many newsletters the recipient has received

        :param statistic_mails_received: The statistic_mails_received of this RecipientGet.
        :type: int
        """
        
        self._statistic_mails_received = statistic_mails_received

    @property
    def statistic_mails_opened(self):
        """
        Gets the statistic_mails_opened of this RecipientGet.
        how many newsletters the recipient has opened

        :return: The statistic_mails_opened of this RecipientGet.
        :rtype: int
        """
        return self._statistic_mails_opened

    @statistic_mails_opened.setter
    def statistic_mails_opened(self, statistic_mails_opened):
        """
        Sets the statistic_mails_opened of this RecipientGet.
        how many newsletters the recipient has opened

        :param statistic_mails_opened: The statistic_mails_opened of this RecipientGet.
        :type: int
        """
        
        self._statistic_mails_opened = statistic_mails_opened

    @property
    def statistic_mails_unique_opened(self):
        """
        Gets the statistic_mails_unique_opened of this RecipientGet.
        how many newsletters the recipient has uniqly opened

        :return: The statistic_mails_unique_opened of this RecipientGet.
        :rtype: int
        """
        return self._statistic_mails_unique_opened

    @statistic_mails_unique_opened.setter
    def statistic_mails_unique_opened(self, statistic_mails_unique_opened):
        """
        Sets the statistic_mails_unique_opened of this RecipientGet.
        how many newsletters the recipient has uniqly opened

        :param statistic_mails_unique_opened: The statistic_mails_unique_opened of this RecipientGet.
        :type: int
        """
        
        self._statistic_mails_unique_opened = statistic_mails_unique_opened

    @property
    def statistic_mails_clicked(self):
        """
        Gets the statistic_mails_clicked of this RecipientGet.
        how often the recipient has clicked on links in newsletters

        :return: The statistic_mails_clicked of this RecipientGet.
        :rtype: int
        """
        return self._statistic_mails_clicked

    @statistic_mails_clicked.setter
    def statistic_mails_clicked(self, statistic_mails_clicked):
        """
        Sets the statistic_mails_clicked of this RecipientGet.
        how often the recipient has clicked on links in newsletters

        :param statistic_mails_clicked: The statistic_mails_clicked of this RecipientGet.
        :type: int
        """
        
        self._statistic_mails_clicked = statistic_mails_clicked

    @property
    def statistic_conversions(self):
        """
        Gets the statistic_conversions of this RecipientGet.
        how often the recipient has converted

        :return: The statistic_conversions of this RecipientGet.
        :rtype: int
        """
        return self._statistic_conversions

    @statistic_conversions.setter
    def statistic_conversions(self, statistic_conversions):
        """
        Sets the statistic_conversions of this RecipientGet.
        how often the recipient has converted

        :param statistic_conversions: The statistic_conversions of this RecipientGet.
        :type: int
        """
        
        self._statistic_conversions = statistic_conversions

    @property
    def statistic_conversions_sum(self):
        """
        Gets the statistic_conversions_sum of this RecipientGet.
        how much the recipient has spent

        :return: The statistic_conversions_sum of this RecipientGet.
        :rtype: float
        """
        return self._statistic_conversions_sum

    @statistic_conversions_sum.setter
    def statistic_conversions_sum(self, statistic_conversions_sum):
        """
        Sets the statistic_conversions_sum of this RecipientGet.
        how much the recipient has spent

        :param statistic_conversions_sum: The statistic_conversions_sum of this RecipientGet.
        :type: float
        """
        
        self._statistic_conversions_sum = statistic_conversions_sum

    @property
    def statistic_last_mail_action(self):
        """
        Gets the statistic_last_mail_action of this RecipientGet.
        when the recipient has had the last interaction with a newsletter

        :return: The statistic_last_mail_action of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_mail_action

    @statistic_last_mail_action.setter
    def statistic_last_mail_action(self, statistic_last_mail_action):
        """
        Sets the statistic_last_mail_action of this RecipientGet.
        when the recipient has had the last interaction with a newsletter

        :param statistic_last_mail_action: The statistic_last_mail_action of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_mail_action = statistic_last_mail_action

    @property
    def statistic_last_mail_received(self):
        """
        Gets the statistic_last_mail_received of this RecipientGet.
        when the recipient has had received the last newsletter

        :return: The statistic_last_mail_received of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_mail_received

    @statistic_last_mail_received.setter
    def statistic_last_mail_received(self, statistic_last_mail_received):
        """
        Sets the statistic_last_mail_received of this RecipientGet.
        when the recipient has had received the last newsletter

        :param statistic_last_mail_received: The statistic_last_mail_received of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_mail_received = statistic_last_mail_received

    @property
    def statistic_last_mail_opened(self):
        """
        Gets the statistic_last_mail_opened of this RecipientGet.
        when the recipient has had opened the last newsletter

        :return: The statistic_last_mail_opened of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_mail_opened

    @statistic_last_mail_opened.setter
    def statistic_last_mail_opened(self, statistic_last_mail_opened):
        """
        Sets the statistic_last_mail_opened of this RecipientGet.
        when the recipient has had opened the last newsletter

        :param statistic_last_mail_opened: The statistic_last_mail_opened of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_mail_opened = statistic_last_mail_opened

    @property
    def statistic_last_mail_clicked(self):
        """
        Gets the statistic_last_mail_clicked of this RecipientGet.
        when the recipient has had clicked the last newsletter

        :return: The statistic_last_mail_clicked of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_mail_clicked

    @statistic_last_mail_clicked.setter
    def statistic_last_mail_clicked(self, statistic_last_mail_clicked):
        """
        Sets the statistic_last_mail_clicked of this RecipientGet.
        when the recipient has had clicked the last newsletter

        :param statistic_last_mail_clicked: The statistic_last_mail_clicked of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_mail_clicked = statistic_last_mail_clicked

    @property
    def statistic_last_mail_converted(self):
        """
        Gets the statistic_last_mail_converted of this RecipientGet.
        when the recipient has had converted the last time

        :return: The statistic_last_mail_converted of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_mail_converted

    @statistic_last_mail_converted.setter
    def statistic_last_mail_converted(self, statistic_last_mail_converted):
        """
        Sets the statistic_last_mail_converted of this RecipientGet.
        when the recipient has had converted the last time

        :param statistic_last_mail_converted: The statistic_last_mail_converted of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_mail_converted = statistic_last_mail_converted

    @property
    def statistic_last_useragent_device(self):
        """
        Gets the statistic_last_useragent_device of this RecipientGet.
        the last useragent device used for opening a newsletter

        :return: The statistic_last_useragent_device of this RecipientGet.
        :rtype: str
        """
        return self._statistic_last_useragent_device

    @statistic_last_useragent_device.setter
    def statistic_last_useragent_device(self, statistic_last_useragent_device):
        """
        Sets the statistic_last_useragent_device of this RecipientGet.
        the last useragent device used for opening a newsletter

        :param statistic_last_useragent_device: The statistic_last_useragent_device of this RecipientGet.
        :type: str
        """
        allowed_values = ["desktop", "mobile", "tablet"]
        if statistic_last_useragent_device not in allowed_values:
            raise ValueError(
                "Invalid value for `statistic_last_useragent_device`, must be one of {0}"
                .format(allowed_values)
            )

        self._statistic_last_useragent_device = statistic_last_useragent_device

    @property
    def statistic_last_useragent_family(self):
        """
        Gets the statistic_last_useragent_family of this RecipientGet.
        the last useragent family used for opening a newsletter

        :return: The statistic_last_useragent_family of this RecipientGet.
        :rtype: str
        """
        return self._statistic_last_useragent_family

    @statistic_last_useragent_family.setter
    def statistic_last_useragent_family(self, statistic_last_useragent_family):
        """
        Sets the statistic_last_useragent_family of this RecipientGet.
        the last useragent family used for opening a newsletter

        :param statistic_last_useragent_family: The statistic_last_useragent_family of this RecipientGet.
        :type: str
        """
        allowed_values = ["lotus_notes", "apple_mail", "thunderbird", "windows_live_mail", "outlook", "iOS", "Android", "Windows", "else"]
        if statistic_last_useragent_family not in allowed_values:
            raise ValueError(
                "Invalid value for `statistic_last_useragent_family`, must be one of {0}"
                .format(allowed_values)
            )

        self._statistic_last_useragent_family = statistic_last_useragent_family

    @property
    def statistic_last_latitude(self):
        """
        Gets the statistic_last_latitude of this RecipientGet.
        the last latitude where the recipient has opened a newsletter

        :return: The statistic_last_latitude of this RecipientGet.
        :rtype: float
        """
        return self._statistic_last_latitude

    @statistic_last_latitude.setter
    def statistic_last_latitude(self, statistic_last_latitude):
        """
        Sets the statistic_last_latitude of this RecipientGet.
        the last latitude where the recipient has opened a newsletter

        :param statistic_last_latitude: The statistic_last_latitude of this RecipientGet.
        :type: float
        """
        
        self._statistic_last_latitude = statistic_last_latitude

    @property
    def statistic_last_longitude(self):
        """
        Gets the statistic_last_longitude of this RecipientGet.
        the last longitude where the recipient has opened a newsletter

        :return: The statistic_last_longitude of this RecipientGet.
        :rtype: float
        """
        return self._statistic_last_longitude

    @statistic_last_longitude.setter
    def statistic_last_longitude(self, statistic_last_longitude):
        """
        Sets the statistic_last_longitude of this RecipientGet.
        the last longitude where the recipient has opened a newsletter

        :param statistic_last_longitude: The statistic_last_longitude of this RecipientGet.
        :type: float
        """
        
        self._statistic_last_longitude = statistic_last_longitude

    @property
    def statistic_last_blacklist_list(self):
        """
        Gets the statistic_last_blacklist_list of this RecipientGet.
        when the recipient was blacklisted the last time

        :return: The statistic_last_blacklist_list of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_blacklist_list

    @statistic_last_blacklist_list.setter
    def statistic_last_blacklist_list(self, statistic_last_blacklist_list):
        """
        Sets the statistic_last_blacklist_list of this RecipientGet.
        when the recipient was blacklisted the last time

        :param statistic_last_blacklist_list: The statistic_last_blacklist_list of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_blacklist_list = statistic_last_blacklist_list

    @property
    def statistic_last_unsubscribe_list(self):
        """
        Gets the statistic_last_unsubscribe_list of this RecipientGet.
        when the recipient was unsubscribed the last time

        :return: The statistic_last_unsubscribe_list of this RecipientGet.
        :rtype: datetime
        """
        return self._statistic_last_unsubscribe_list

    @statistic_last_unsubscribe_list.setter
    def statistic_last_unsubscribe_list(self, statistic_last_unsubscribe_list):
        """
        Sets the statistic_last_unsubscribe_list of this RecipientGet.
        when the recipient was unsubscribed the last time

        :param statistic_last_unsubscribe_list: The statistic_last_unsubscribe_list of this RecipientGet.
        :type: datetime
        """
        
        self._statistic_last_unsubscribe_list = statistic_last_unsubscribe_list

    @property
    def statistic_last_blacklist_list_reason(self):
        """
        Gets the statistic_last_blacklist_list_reason of this RecipientGet.
        the reason the recipient got blacklisted the last time

        :return: The statistic_last_blacklist_list_reason of this RecipientGet.
        :rtype: str
        """
        return self._statistic_last_blacklist_list_reason

    @statistic_last_blacklist_list_reason.setter
    def statistic_last_blacklist_list_reason(self, statistic_last_blacklist_list_reason):
        """
        Sets the statistic_last_blacklist_list_reason of this RecipientGet.
        the reason the recipient got blacklisted the last time

        :param statistic_last_blacklist_list_reason: The statistic_last_blacklist_list_reason of this RecipientGet.
        :type: str
        """
        
        self._statistic_last_blacklist_list_reason = statistic_last_blacklist_list_reason

    @property
    def statistic_last_unsubscribe_list_reason(self):
        """
        Gets the statistic_last_unsubscribe_list_reason of this RecipientGet.
        the reason the recipient got unsubscribed the last time

        :return: The statistic_last_unsubscribe_list_reason of this RecipientGet.
        :rtype: str
        """
        return self._statistic_last_unsubscribe_list_reason

    @statistic_last_unsubscribe_list_reason.setter
    def statistic_last_unsubscribe_list_reason(self, statistic_last_unsubscribe_list_reason):
        """
        Sets the statistic_last_unsubscribe_list_reason of this RecipientGet.
        the reason the recipient got unsubscribed the last time

        :param statistic_last_unsubscribe_list_reason: The statistic_last_unsubscribe_list_reason of this RecipientGet.
        :type: str
        """
        
        self._statistic_last_unsubscribe_list_reason = statistic_last_unsubscribe_list_reason

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

